@@ -1,10 +1,11 @@
 from typing import List
 
-from pydantic import BaseModel, AnyHttpUrl
+from pydantic import AnyHttpUrl, BaseModel
 
 
 class ConformanceClasses(BaseModel):
     """
     https://github.com/radiantearth/stac-api-spec/blob/master/api-spec.md#ogc-api---features-endpoints
     """
-    conformsTo: List[AnyHttpUrl]
\ No newline at end of file
+
+    conformsTo: List[AnyHttpUrl]
